==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/export/rss_sfnewreleases.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: rss_sfnewreleases.php,v 1.6 2004/01/31 00:56:18 yeupou Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// ## export sf front page news in RSS
require "../include/pre.php";
include "rss_utils.inc";
header("Content-Type: text/plain");
print '<?xml version="1.0"?>
<!DOCTYPE rss SYSTEM "http://my.netscape.com/publish/formats/rss-0.91.dtd">
<rss version="0.91">
';
// ## default limit
if (!$limit) $limit = 10;
if ($limit > 100) $limit = 100;

$res = db_query("SELECT groups.group_name AS group_name,"
	. "groups.group_id AS group_id,"
	. "groups.unix_group_name AS unix_group_name,"
	. "groups.short_description AS short_description,"
	. "groups.license AS license,"
	. "groups.file_downloads AS file_downloads,"
	. "user.user_name AS user_name,"
	. "user.user_id AS user_id,"
	. "filemodule.filemodule_id AS filemodule_id,"
	. "filemodule.module_name AS module_name,"
	. "filerelease.release_time AS release_time,"
	. "filerelease.filename AS filename,"
	. "filerelease.release_version AS release_version,"
	. "filerelease.filerelease_id AS filerelease_id "
	. "FROM user,filerelease,filemodule,groups WHERE "
	. "filerelease.user_id=user.user_id AND "
	. "filerelease.group_id=groups.group_id AND "
	. "filerelease.filemodule_id=filemodule.filemodule_id "
	. "ORDER BY filerelease.release_time DESC LIMIT ".($limit * 3));


// ## one time output
print " <channel>\n";
print "  <copyright>Copyright 1999-2000 VA Linux Systems, Inc.</copyright>\n";
print "  <pubDate>".gmdate('D, d M Y g:i:s',time())." GMT</pubDate>\n";
print "  <description>SourceForge New Releases</description>\n";
print "  <link>http://$GLOBALS[sys_default_domain]</link>\n";
print "  <title>SourceForge New Releases</title>\n";
print "  <webMaster>webmaster@$GLOBALS[sys_default_domain]</webMaster>\n";
print "  <language>en-us</language>\n";
// ## item outputs
$outputtotal = 0;
while ($row = db_fetch_array($res)) {
	if (!$G_RELEASE["$row[group_id]"]) {
		print "  <item>\n";
		print "   <title>".htmlspecialchars($row[group_name])."</title>\n";
		print "   <link>http://$GLOBALS[sys_default_domain]/project/filelist.php?group_id=$row[group_id]</link>\n";
		print "   <description>".rss_description($row[short_description])."</description>\n";
		print "  </item>\n";
		$outputtotal++;
	}
	// ## eliminate dupes, only do $limit of these
	$G_RELEASE["$row[group_id]"] = 1;
	if ($outputtotal >= $limit) break;
}
// ## end output
print " </channel>\n";
?>
</rss>

==> savane-1.0.8+2.tar.gz: savane-1.0.8+2/frontend/php/export/rss_sfnewreleases.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: rss_sfnewreleases.php,v 1.7 2005/06/30 17:19:34 toddy Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
// The Savane project is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// The Savane project is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Savane project; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
// ## export sf front page news in RSS
require "../include/pre.php";
include "rss_utils.inc";
header("Content-Type: text/plain");
print '<?xml version="1.0"?>
<!DOCTYPE rss SYSTEM "http://my.netscape.com/publish/formats/rss-0.91.dtd">
<rss version="0.91">
';
// ## default limit
if (!$limit) $limit = 10;
if ($limit > 100) $limit = 100;

$res = db_query("SELECT groups.group_name AS group_name,"
	. "groups.group_id AS group_id,"
	. "groups.unix_group_name AS unix_group_name,"
	. "groups.short_description AS short_description,"
	. "groups.license AS license,"
	. "groups.file_downloads AS file_downloads,"
	. "user.user_name AS user_name,"
	. "user.user_id AS user_id,"
	. "filemodule.filemodule_id AS filemodule_id,"
	. "filemodule.module_name AS module_name,"
	. "filerelease.release_time AS release_time,"
	. "filerelease.filename AS filename,"
	. "filerelease.release_version AS release_version,"
	. "filerelease.filerelease_id AS filerelease_id "
	. "FROM user,filerelease,filemodule,groups WHERE "
	. "filerelease.user_id=user.user_id AND "
	. "filerelease.group_id=groups.group_id AND "
	. "filerelease.filemodule_id=filemodule.filemodule_id "
	. "ORDER BY filerelease.release_time DESC LIMIT ".($limit * 3));


// ## one time output
print " <channel>\n";
print "  <copyright>Copyright 1999-2000 VA Linux Systems, Inc.</copyright>\n";
print "  <pubDate>".gmdate('D, d M Y g:i:s',time())." GMT</pubDate>\n";
print "  <description>SourceForge New Releases</description>\n";
print "  <link>http://$GLOBALS[sys_default_domain]</link>\n";
print "  <title>SourceForge New Releases</title>\n";
print "  <webMaster>webmaster@$GLOBALS[sys_default_domain]</webMaster>\n";
print "  <language>en-us</language>\n";
// ## item outputs
$outputtotal = 0;
while ($row = db_fetch_array($res)) {
	if (!$G_RELEASE["$row[group_id]"]) {
		print "  <item>\n";
		print "   <title>".htmlspecialchars($row[group_name])."</title>\n";
		print "   <link>http://$GLOBALS[sys_default_domain]/project/filelist.php?group_id=$row[group_id]</link>\n";
		print "   <description>".rss_description($row[short_description])."</description>\n";
		print "  </item>\n";
		$outputtotal++;
	}
	// ## eliminate dupes, only do $limit of these
	$G_RELEASE["$row[group_id]"] = 1;
	if ($outputtotal >= $limit) break;
}
// ## end output
print " </channel>\n";
?>
</rss>
